@@ -278,6 +278,10 @@ The lock manager drivers
 
 The Hyper-V driver
 
+=item Sys::Virt::Error::FROM_CAPABILITIES
+
+The capabilities driver
+
 =back
 
 =head2 ERROR CODES
@@ -584,6 +588,10 @@ Probing the storage pool failed
 
 Reverting the snapshot could cause data loss
 
+=item Sys::Virt::Error::ERR_OPERATION_ABORTED
+
+The asynchronous operation was aborted at admin request
+
 =back
 
 =head1 AUTHORS
